package INI::Examples;

our $DATE = '2019-04-23'; # DATE
our $VERSION = '0.001'; # VERSION

1;
# ABSTRACT: Example INI configuration files

__END__

=pod

=encoding UTF-8

=head1 NAME

INI::Examples - Example INI configuration files

=head1 VERSION

This document describes version 0.001 of INI::Examples (from Perl distribution INI-Examples), released on 2019-04-23.

=head1 DESCRIPTION

This distribution contains various examples of INI configuration files in its
per-dist share dir.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/INI-Examples>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-INI-Examples>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=INI-Examples>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

Some modules to parse INI files: L<Config::INI::Reader>, L<Config::IniFiles>,
L<Config::IOD::INI::Reader>.

Related examples: L<IOD::Examples>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
